@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+# Used to mock validate method on tests
+from pluct import resource
+resources = resource
 
 # Shortcuts
 from pluct.resource import Resource  # noqa
